@@ -632,6 +632,60 @@ our @TEST = (
             ];
         },
     ],
+    [
+        'handle Authorization header',
+        sub {
+            my $cb  = shift;
+            SKIP: {
+                skip "Authorization header is unsupported under CGI", 4 if ($ENV{PLACK_TEST_HANDLER} || "") eq "CGI";
+
+                {
+                    my $req = HTTP::Request->new(
+                        GET => "http://127.0.0.1/",
+                    );
+                    $req->push_header(Authorization => 'Basic XXXX');
+                    my $res = $cb->($req);
+                    is $res->header('X-AUTHORIZATION'), 1;
+                    is $res->content, 'Basic XXXX';
+                };
+
+                {
+                    my $req = HTTP::Request->new(
+                        GET => "http://127.0.0.1/",
+                    );
+                    my $res = $cb->($req);
+                    is $res->header('X-AUTHORIZATION'), 0;
+                    is $res->content, '';
+                };
+            };
+        },
+        sub {
+            my $env = shift;
+            return [
+                200,
+                [ 'Content-Type' => 'text/plain', 'X-AUTHORIZATION' => exists($env->{HTTP_AUTHORIZATION}) ? 1 : 0 ],
+                [ $env->{HTTP_AUTHORIZATION} ],
+            ];
+        },
+    ],
+    [
+        'repeated slashes',
+        sub {
+            my $cb = shift;
+            my $res = $cb->(GET "http://127.0.0.1/foo///bar/baz");
+            is $res->code, 200;
+            is $res->header('content_type'), 'text/plain';
+            is $res->content, '/foo///bar/baz';
+        },
+        sub {
+            my $env = shift;
+            return [
+                200,
+                [ 'Content-Type' => 'text/plain', ],
+                [ $env->{PATH_INFO} ],
+            ];
+        },
+    ],
 );
 
 sub runtests {
